Hello World! | Crotal
Author: user
Description: Welcome to Crotal, This is the first post, modify or remove it, and start your own blog!

# Crotal

A static site generator written in Python.

Posted by user on Nov 25,2012

## Hello World!

Welcome to Crotal, This is the first post, modify or remove it, and start your own blog!

Write you post like this:

    ---
    title: "Hello, World"
    date: 2013-04-20 15:10
    categories: crotal
    slug: hello-world
    ---

    Welcome to Crotal, This is your first post, modify or remove it, and start your own blog!

Add a picture like this:

    ![octocat](/images/crotal.png)

Check the documents for more information.

comments powered by Disqus